=======
Credits
=======

Development Lead
----------------

* John Turner <john@springmoves.com>

Contributors
------------

None yet. Why not be the first?

Additional Credits
------------------

This project was inspired by Alex Kehayia's django_cohorts_

.. _django_cohorts: http://alexkehayias.tumblr.com/post/18608787713/cohort-analysis-django

Work on this project was original undertaken at SpringMoves_.

.. _SpringMoves: http://www.springmoves.com
